aboutsummaryrefslogtreecommitdiff
path: root/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
diff options
context:
space:
mode:
authorMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2023-08-03 15:20:05 +0200
committerMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2023-08-29 11:54:29 +0200
commitfaf70c1f330a92612cf381d32c791e9ba445d3f2 (patch)
treebabcb4d01a57463c1b8c5dffbd9c57d44c4baa49 /ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
parentfa8996b930886da712c09ffe4b58016b36c2ae5b (diff)
downloadbitcoin-faf70c1f330a92612cf381d32c791e9ba445d3f2.tar.xz
Bump python minimum version to 3.9
Diffstat (limited to 'ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh')
-rwxr-xr-xci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh b/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
index 454a4b8dff..2d181f1bb8 100755
--- a/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
+++ b/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
@@ -7,9 +7,9 @@
export LC_ALL=C.UTF-8
export CONTAINER_NAME=ci_native_nowallet_libbitcoinkernel
-export CI_IMAGE_NAME_TAG="docker.io/ubuntu:20.04"
-# Use minimum supported python3.8 and clang-10, see doc/dependencies.md
-export PACKAGES="python3-zmq clang-10 llvm-10 libc++abi-10-dev libc++-10-dev"
-export DEP_OPTS="NO_WALLET=1 CC=clang-10 CXX='clang++-10 -stdlib=libc++'"
+export CI_IMAGE_NAME_TAG="docker.io/debian:bullseye"
+# Use minimum supported python3.9 and clang-10 (or best-effort clang-11), see doc/dependencies.md
+export PACKAGES="python3-zmq clang-11 llvm-11 libc++abi-11-dev libc++-11-dev"
+export DEP_OPTS="NO_WALLET=1 CC=clang-11 CXX='clang++-11 -stdlib=libc++'"
export GOAL="install"
export BITCOIN_CONFIG="--enable-reduce-exports --enable-experimental-util-chainstate --with-experimental-kernel-lib --enable-shared"